aboutsummaryrefslogtreecommitdiffstats
path: root/libjulia/Exceptions.h
diff options
context:
space:
mode:
Diffstat (limited to 'libjulia/Exceptions.h')
-rw-r--r--libjulia/Exceptions.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/libjulia/Exceptions.h b/libjulia/Exceptions.h
index 20ab6520..48624a56 100644
--- a/libjulia/Exceptions.h
+++ b/libjulia/Exceptions.h
@@ -15,7 +15,7 @@
along with solidity. If not, see <http://www.gnu.org/licenses/>.
*/
/**
* Exceptions in Julia.
*/
#pragma once
@@ -28,8 +28,8 @@ namespace dev
namespace julia
{
-struct IuliaException: virtual Exception {};
-struct OptimizerException: virtual IuliaException {};
+struct YulException: virtual Exception {};
+struct OptimizerException: virtual YulException {};
}
}
@@ -15,7 +15,7 @@
*/
/**
- * Exceptions in Julia.
+ * Exceptions in Yul.
*/
#pragma once